@@ -4,6 +4,7 @@ from tkinter import filedialog
 
 import click
 import click.core
+import tkcalendar as tkc
 
 
 class TkCommandView:
@@ -51,8 +52,9 @@ class TkCommandView:
             param_list = param_list + arg.value()
 
         for opt in self.opt_views_list:
-            param_list = param_list + opt.value()
-
+            if opt.is_value_present():
+                param_list = param_list + opt.value()
+        click.echo(param_list)
         try:
             self.cmd.main(args=param_list)
         finally:
@@ -60,8 +62,6 @@ class TkCommandView:
 
     def __call__(self, *args, **kwargs):
         self.app.mainloop()
-        # self.invoke_cmd()
-        pass
 
 
 class ParamView(tk.LabelFrame):
@@ -87,7 +87,14 @@ class ParamView(tk.LabelFrame):
         # var: tk.StringVar = tk.StringVar()
         self.values.append(var)
         if hasattr(self, 'tk_input_type'):
-            in_put = self.tk_input_type(self, variable=var, text=self.param.human_readable_name)
+            if hasattr(self, 'init_params') and not hasattr(self, 'init_vars'):
+                in_put = self.tk_input_type(self, **self.init_params)
+            elif not hasattr(self, 'init_params') and hasattr(self, 'init_vars'):
+                in_put = self.tk_input_type(self, *self.init_vars)
+            elif hasattr(self, 'init_params') and hasattr(self, 'init_vars'):
+                in_put = self.tk_input_type(self, *self.init_vars, **self.init_params)
+            else:
+                in_put = self.tk_input_type(self, variable=var, text=self.param.human_readable_name)
         else:
             in_put = tk.Entry(self, textvariable=var)
         in_put.pack(fill=tk.X)
@@ -96,19 +103,28 @@ class ParamView(tk.LabelFrame):
     def value(self):
         return_list: list = []
         if type(self.inputs) == list:
-            for i in self.values:
+            for i in self.inputs:
                 if type(self.param) == click.core.Option:
                     return_list.append(self.param.opts[0])
                 return_list.append(i.get())
         else:
-            if type(self.param) == click.core.Option:
+            if type(self.param) == click.core.Option and self.inputs.get():
                 return_list.append(self.param.opts[0])
-            return_list.append(self.values[0].get())
+            if self.inputs.get():
+                return_list.append(self.inputs.get())
         return return_list
 
+    def is_value_present(self):
+        # TODO: Implement Validation Logic
+        if not isinstance(self.inputs, list):
+            return self.inputs.get()
+        else:
+            return True
+
 
 class BoolParamView(ParamView):
     def __init__(self, param: click.Parameter, master: tk.Tk):
+        # TODO: Bool Params are not multi input. Adjust accordingly
         self.tk_input_type = tk.Checkbutton
         self.tk_var_type = tk.BooleanVar
         super().__init__(param, master)
@@ -119,6 +135,10 @@ class BoolParamView(ParamView):
             return_list.append(self.param.opts[0])
         return return_list
 
+    def is_value_present(self):
+        # TODO: Implement Validation Logic
+        return self.values[0].get()
+
 
 class ObjectView(ParamView):
 
@@ -132,8 +152,11 @@ class ContextView(ParamView):
         super().__init__(ctx, master)
 
 
-class PathParamView(ParamView):
+class FileParamView(ParamView):
     def __init__(self, param: click.Parameter, master: tk.Tk):
+        # Fixme: Find event binding for tkinter entry
+        # and implement StringVar update on event of
+        # Key release or paste
         self.tk_input_type = TkFileSelectorView
         self.tk_var_type = tk.StringVar
         super().__init__(param, master)
@@ -141,21 +164,22 @@ class PathParamView(ParamView):
     def value(self):
         return_list: list = []
         if type(self.inputs) == list:
-            for i in self.values:
+            for i in self.inputs:
                 if type(self.param) == click.core.Option:
                     return_list.append(self.param.opts[0])
                 return_list.append(i.get())
         else:
-            if type(self.param) == click.core.Option:
+            if type(self.param) == click.core.Option is self.inputs.get():
                 return_list.append(self.param.opts[0])
-            return_list.append(self.values[0].get())
+            if self.inputs.get():
+                return_list.append(self.inputs.get())
         return return_list
 
 
 class TkFileSelectorView(tk.Entry):
 
     def __init__(self, master=None, variable=None, text='File', btn_text='Browse'):
-        # Fixme: Find eventbinding for tkinter entry
+        # Fixme: Find event binding for tkinter entry
         # and implement StringVar update on event of
         # Key release or paste
         super().__init__(master, textvariable=variable, text=text)
@@ -166,17 +190,94 @@ class TkFileSelectorView(tk.Entry):
     def set_file(self):
         file_path: str = filedialog.askopenfilename()
         self.var.set(file_path)
+        self.delete(0)
+        self.insert(0, file_path)
+
+
+class TkPathSelectorView(TkFileSelectorView):
+    def set_file(self):
+        file_path: str = filedialog.askdirectory()
+        self.var.set(file_path)
+        self.delete(0)
+        self.insert(0, file_path)
+
+
+class PathParamView(FileParamView):
+    def __init__(self, param: click.Parameter, master: tk.Tk):
+        self.tk_input_type = TkPathSelectorView
+        self.tk_var_type = tk.StringVar
+        super().__init__(param, master)
+
+
+class ChoiceView(ParamView):
+    def __init__(self, param: click.Parameter, master: tk.Tk):
+        self.tk_input_type = tk.OptionMenu
+        self.tk_var_type = tk.StringVar
+        self.tk_var = tk.StringVar()
+        self.init_vars = (
+            self.tk_var,
+            *param.type.choices
+        )
+        super().__init__(param, master)
+
+        def value(self):
+            return ''
+
+
+class DateTimeView(ParamView):
+    def __init__(self, param: click.Parameter, master: tk.Tk):
+        # FIXME: Invalid Format :/
+        self.tk_input_type = tkc.DateEntry
+        self.tk_var_type = tk.StringVar
+        self.tk_var = tk.StringVar()
+        self.init_params = {
+            'textvariable': self.tk_var
+        }
+        super().__init__(param, master)
+
+
+class IntView(ParamView):
+    def __init__(self, param: click.Parameter, master: tk.Tk):
+        self.tk_input_type = tk.Entry
+        self.tk_var_type = tk.StringVar
+        self.tk_var = tk.StringVar()
+        self.init_params = {
+            'textvariable': self.tk_var
+        }
+        super().__init__(param, master)
+
+
+class FloatView(ParamView):
+    def __init__(self, param: click.Parameter, master: tk.Tk):
+        self.tk_input_type = tk.Entry
+        self.tk_var_type = tk.StringVar
+        self.tk_var = tk.StringVar()
+        self.init_params = {
+            'textvariable': self.tk_var
+        }
+        super().__init__(param, master)
+
+
+class UuidView(ParamView):
+    def __init__(self, param: click.Parameter, master: tk.Tk):
+        self.tk_input_type = tk.Entry
+        self.tk_var_type = tk.StringVar
+        self.tk_var = tk.StringVar()
+        self.init_params = {
+            'textvariable': self.tk_var
+        }
+        super().__init__(param, master)
 
 
 view_mapping: dict = {
     click.types.StringParamType: ParamView,
     click.types.UnprocessedParamType: ParamView,
-    click.types.Choice: ParamView,
-    click.types.DateTime: ParamView,
-    click.types.IntParamType: ParamView,
-    click.types.FloatParamType: ParamView,
+    click.types.Choice: ChoiceView,
+    click.types.DateTime: DateTimeView,
+    click.types.IntParamType: IntView,
+    click.types.FloatParamType: FloatView,
     click.types.BoolParamType: BoolParamView,
-    click.types.UUIDParameterType: ParamView,
-    click.types.File: PathParamView,
-    click.types.Path: ParamView,
+    click.types.UUIDParameterType: UuidView,
+    click.types.File: FileParamView,
+    click.types.Path: PathParamView,
 }
